pub struct B2filter {
pub category_bits: u16,
pub mask_bits: u16,
pub group_index: i16,
}Expand description
This holds contact filtering data.
Fields
category_bits: u16The collision category bits. Normally you would just set one bit.
mask_bits: u16The collision mask bits. This states the categories that this shape would accept for collision.
group_index: i16Collision groups allow a certain group of objects to never collide (negative) or always collide (positive). Zero means no collision group. Non-zero group filtering always wins against the mask bits.