B2fixtureDef

Struct B2fixtureDef 

pub struct B2fixtureDef<D: UserDataType> {
    pub shape: Option<ShapeDefPtr>,
    pub user_data: Option<D::Fixture>,
    pub friction: f32,
    pub restitution: f32,
    pub restitution_threshold: f32,
    pub density: f32,
    pub is_sensor: bool,
    pub filter: B2filter,
}
A fixture definition is used to create a fixture. This class defines an abstract fixture definition. You can reuse fixture definitions safely.

Fields

shape: Option<ShapeDefPtr>

The shape, this must be set. The shape will be cloned, so you can create the shape on the stack.

user_data: Option<D::Fixture>

Use this to store application specific fixture data.

friction: f32

The friction coefficient, usually in the range [0,1].

restitution: f32

The restitution (elasticity) usually in the range [0,1].

restitution_threshold: f32

Restitution velocity threshold, usually in m/s. Collisions above this speed have restitution applied (will bounce).

density: f32

The density, usually in kg/m^2.

is_sensor: bool

A sensor shape collects contact information but never generates a collision response.

filter: B2filter

Contact filtering data.