B2growableStack

Struct B2growableStack 

pub struct B2growableStack<T: Copy + Default, const N: usize> { /* private fields */ }
This is a growable LIFO stack with an initial capacity of n. If the stack size exceeds the initial capacity, the heap is used to increase the size of the stack.

Implementations

Source

impl<T: Copy + Default, const N: usize> B2growableStack<T, N>

pub fn new() -> Self

pub fn push(&mut self, element: &T)

pub fn pop(&mut self) -> T

pub fn get_count(&self) -> usize