B2jointDef

Struct B2jointDef 

pub struct B2jointDef<D: UserDataType> {
    pub jtype: B2jointType,
    pub user_data: Option<D::Joint>,
    pub body_a: Option<BodyPtr<D>>,
    pub body_b: Option<BodyPtr<D>>,
    pub collide_connected: bool,
}
Joint definitions are used to construct joints.

Fields

jtype: B2jointType

The joint type is set automatically for concrete joint types.

user_data: Option<D::Joint>

Use this to attach application specific data to your joints.

body_a: Option<BodyPtr<D>>

The first attached body.

body_b: Option<BodyPtr<D>>

The second attached body.

collide_connected: bool

Set this flag to true if the attached bodies should collide.