B2Mat33

Struct B2Mat33 

pub struct B2Mat33 {
    pub ex: B2Vec3,
    pub ey: B2Vec3,
    pub ez: B2Vec3,
}
A 3-by-3 matrix. Stored in column-major order.

Fields

ex: B2Vec3ey: B2Vec3ez: B2Vec3

Implementations

Source

impl B2Mat33

pub fn new(c1: B2Vec3, c2: B2Vec3, c3: B2Vec3) -> B2Mat33

Construct this matrix using columns.

pub fn set_zero(&mut self)

Set this matrix to all zeros.

pub fn zero() -> Self

pub fn solve33(self, b: B2Vec3) -> B2Vec3

solve A * x = b, where b is a column vector. This is more efficient than computing the inverse in one-shot cases.

pub fn solve22(self, b: B2vec2) -> B2vec2

solve A * x = b, where b is a column vector. This is more efficient than computing the inverse in one-shot cases. solve only the upper 2-by-2 matrix equation.

pub fn get_inverse22(self, m: &mut B2Mat33)

Get the inverse of this matrix as a 2-by-2. Returns the zero matrix if singular.

pub fn get_sym_inverse33(self, m: &mut B2Mat33)

Get the symmetric inverse of this matrix as a 3-by-3. Returns the zero matrix if singular.