pub struct B2massData {
pub mass: f32,
pub center: B2vec2,
pub i: f32,
}Expand description
This holds the mass data computed for a shape.
Fields
mass: f32The mass of the shape, usually in kilograms.
center: B2vec2The position of the shape’s centroid relative to the shape’s origin.
i: f32The rotational inertia of the shape about the local origin.