pub struct B2growableStack<T: Copy + Default, const N: usize> { /* private fields */ }Expand description
This is a growable LIFO stack with an initial capacity of n. If the stack size exceeds the initial capacity, the heap is used to increase the size of the stack.
Implementations