pub struct B2Mat33 {
pub ex: B2Vec3,
pub ey: B2Vec3,
pub ez: B2Vec3,
}Expand description
A 3-by-3 matrix. Stored in column-major order.
Fields
ex: B2Vec3ey: B2Vec3ez: B2Vec3Implementations
Sourceimpl B2Mat33
impl B2Mat33
pub fn zero() -> Self
Sourcepub fn solve33(self, b: B2Vec3) -> B2Vec3
pub fn solve33(self, b: B2Vec3) -> B2Vec3
solve A * x = b, where b is a column vector. This is more efficient than computing the inverse in one-shot cases.
Sourcepub fn solve22(self, b: B2vec2) -> B2vec2
pub fn solve22(self, b: B2vec2) -> B2vec2
solve A * x = b, where b is a column vector. This is more efficient than computing the inverse in one-shot cases. solve only the upper 2-by-2 matrix equation.
Sourcepub fn get_inverse22(self, m: &mut B2Mat33)
pub fn get_inverse22(self, m: &mut B2Mat33)
Get the inverse of this matrix as a 2-by-2. Returns the zero matrix if singular.
Sourcepub fn get_sym_inverse33(self, m: &mut B2Mat33)
pub fn get_sym_inverse33(self, m: &mut B2Mat33)
Get the symmetric inverse of this matrix as a 3-by-3. Returns the zero matrix if singular.